==> at_contacts_group_flutter-1.0.0.tar.gz: lib/widgets/error_screen.dart <==
import 'package:at_common_flutter/widgets/custom_button.dart';
import 'package:at_contacts_group_flutter/utils/colors.dart';
import 'package:flutter/material.dart';
import 'package:at_common_flutter/at_common_flutter.dart';

class ErrorScreen extends StatelessWidget {
  final Function onPressed;
  final String msg;
  ErrorScreen(
      {this.onPressed, this.msg = 'Something went wrong, please retry.'});
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Text(msg,
              textAlign: TextAlign.center, style: TextStyle(fontSize: 20)),
          SizedBox(height: 10),
          onPressed != null
              ? CustomButton(
                  buttonText: 'Retry',
                  width: 120.toWidth,
                  height: 40.toHeight,
                  onPressed: () async {
                    if (this.onPressed != null) {
                      onPressed();
                    }
                  },
                  buttonColor: Theme.of(context).brightness == Brightness.light
                      ? AllColors().Black
                      : AllColors().WHITE,
                  fontColor: Theme.of(context).brightness == Brightness.light
                      ? AllColors().WHITE
                      : AllColors().Black,
                )
              : SizedBox()
        ],
      ),
    );
  }
}

==> at_contacts_group_flutter-2.0.1.tar.gz: lib/widgets/error_screen.dart <==
// ignore: import_of_legacy_library_into_null_safe
import 'package:at_common_flutter/widgets/custom_button.dart';
import 'package:at_contacts_group_flutter/utils/colors.dart';
import 'package:flutter/material.dart';
// ignore: import_of_legacy_library_into_null_safe
import 'package:at_common_flutter/at_common_flutter.dart';

class ErrorScreen extends StatelessWidget {
  final Function? onPressed;
  final String msg;
  ErrorScreen(
      {this.onPressed, this.msg = 'Something went wrong, please retry.'});
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Text(msg,
              textAlign: TextAlign.center, style: TextStyle(fontSize: 20)),
          SizedBox(height: 10),
          onPressed != null
              ? CustomButton(
                  buttonText: 'Retry',
                  width: 120.toWidth,
                  height: 40.toHeight,
                  onPressed: () async {
                    if (onPressed != null) {
                      onPressed!();
                    }
                  },
                  buttonColor: Theme.of(context).brightness == Brightness.light
                      ? AllColors().Black
                      : AllColors().WHITE,
                  fontColor: Theme.of(context).brightness == Brightness.light
                      ? AllColors().WHITE
                      : AllColors().Black,
                )
              : SizedBox()
        ],
      ),
    );
  }
}
